@@ -23,14 +23,28 @@ R_CallMethodDef CallMethods[] = {
   { "Rkdtree",(DL_FUNC)&Rkdtree,1},
   {"Rkdnearest",(DL_FUNC)&Rkdnearest,4},
   {"Rkradius",(DL_FUNC)&Rkradius,5},
+  {"sXWXd",(DL_FUNC)&sXWXd,5},
+  {"sXbd",(DL_FUNC)&sXbd,3},
+  {"sXyd",(DL_FUNC)&sXyd,3},
+  {"sdiagXVXt",(DL_FUNC)&sdiagXVXt,4},
+  {"stmm",(DL_FUNC)&stmm,1},
+  {"AddBVB",(DL_FUNC)&AddBVB,3},
+  {"isa1p",(DL_FUNC)&isa1p,3},
+  {"mrow_sum",(DL_FUNC)&mrow_sum,3},
+  {"ncv",(DL_FUNC)&ncv,17},
+  {"Rncv",(DL_FUNC)&Rncv,19},
+  {"ncvls",(DL_FUNC)&ncvls,18},
+  {"Rncvls",(DL_FUNC)&Rncvls,19},
+  {"nei_cov",(DL_FUNC)&nei_cov,4},
   {NULL, NULL, 0}
 };
 
 R_CMethodDef CEntries[] = { 
     {"band_chol",(DL_FUNC) band_chol,4},
+    {"davies",(DL_FUNC) davies,10},
     {"tri_chol",(DL_FUNC) tri_chol,4},
     {"diagXVXt", (DL_FUNC) &diagXVXt,21},
-    {"XWXd", (DL_FUNC) &XWXd,18},
+    //    {"XWXd", (DL_FUNC) &XWXd,18},
     {"XWXd0", (DL_FUNC) &XWXd0,18},
     {"XWXd1", (DL_FUNC) &XWXd1,22},
     {"XWyd", (DL_FUNC) &XWyd,21},
@@ -65,6 +79,7 @@ R_CMethodDef CEntries[] = {
     {"mgcv_tri_diag",(DL_FUNC)&mgcv_tri_diag,3},
     {"mgcv_td_qy",(DL_FUNC)&mgcv_td_qy,7},
     {"mgcv_symeig",(DL_FUNC)&mgcv_symeig,6},
+    {"mgcv_trisymeig",(DL_FUNC)&mgcv_trisymeig,6},
     {"read_mat",(DL_FUNC)&read_mat,4},
     {"rwMatrix",(DL_FUNC)&rwMatrix,8},
     {"in_out",(DL_FUNC)&in_out,8},
@@ -86,6 +101,9 @@ R_CMethodDef CEntries[] = {
     {"mgcv_pqr",(DL_FUNC)&mgcv_pqr,6},
     {"getRpqr",(DL_FUNC)&getRpqr,6},
     {"mgcv_pqrqy",(DL_FUNC)&mgcv_pqrqy,8},
+    {"minres",(DL_FUNC)&minres,7},
+    {"Zb",(DL_FUNC)&Zb,6},
+    {"Ztb",(DL_FUNC)&Ztb,7},
     {NULL, NULL, 0}
 };
 
@@ -93,7 +111,7 @@ void R_init_mgcv(DllInfo *dll)
 {
     R_registerRoutines(dll, CEntries, CallMethods, NULL, NULL);
     R_useDynamicSymbols(dll, FALSE);
-    R_RegisterCCallable("mgcv","mgcv_pmmult2", (DL_FUNC) &mgcv_pmmult2); 
+    R_RegisterCCallable("mgcv","mgcv_pmmult2", (DL_FUNC) &mgcv_pmmult2); // allows calling from other packages
     R_RegisterCCallable("mgcv","pls_fit1", (DL_FUNC) &pls_fit1);
     R_RegisterCCallable("mgcv","gdi2", (DL_FUNC) &gdi2); 
 }
